@@ -7,7 +7,7 @@ Defines the following:
     - number = digits
     - alnum = digits or lower and upper case alphabet
     - identifier = first(alpha) rest(alnum | '_')
-    - qualified = first(alpha) rest(alnum | '.')
+    - qualified = first(alpha) rest(alnum | '.' | '_')
     - integer = first(number | '-') rest(number)
 """
 __author__ = 'Taylor "Nekroze" Lawson'
@@ -26,7 +26,7 @@ def _identifier_rest(char):
 identifier = (alpha, _identifier_rest)
 
 def _qualified_rest(char):
-    return alnum(char) or char == '.'
+    return alnum(char) or char in '_.'
 
 qualified = (alpha, _qualified_rest)
 
